<?php
/**
 * Electrician Services functions and definitions
 *
 * @subpackage Electrician Services
 * @since 1.0
 */

//woocommerce//
//shop page no of columns
function electrician_services_woocommerce_loop_columns() {
	
	$retrun = get_theme_mod( 'electrician_services_archieve_item_columns', 3 );
    
    return $retrun;
}
add_filter( 'loop_shop_columns', 'electrician_services_woocommerce_loop_columns' );
function electrician_services_woocommerce_products_per_page() {

		$retrun = get_theme_mod( 'electrician_services_archieve_shop_perpage', 6 );
    
    return $retrun;
}
add_filter( 'loop_shop_per_page', 'electrician_services_woocommerce_products_per_page' );
// related products
function electrician_services_related_products_args( $args ) {
    $defaults = array(
        'posts_per_page' => get_theme_mod( 'electrician_services_related_shop_perpage', 3 ),
        'columns'        => get_theme_mod( 'electrician_services_related_item_columns', 3),
    );

    $args = wp_parse_args( $defaults, $args );

    return $args;
}
add_filter( 'woocommerce_output_related_products_args', 'electrician_services_related_products_args' );
function electrician_services_related_products_heading($electrician_services_translated_text, $text, $domain) {
    $electrician_services_heading = get_theme_mod('woocommerce_related_products_heading', 'Related products');

    if ($text === 'Related products' && $domain === 'woocommerce') {
        $electrician_services_translated_text = $electrician_services_heading;
    }
    return $electrician_services_translated_text;
}
add_filter('gettext', 'electrician_services_related_products_heading', 20, 3);
// breadcrumb seperator
function electrician_services_woocommerce_breadcrumb_separator($electrician_services_defaults) {
    $electrician_services_separator = get_theme_mod('woocommerce_breadcrumb_separator', ' / ');

    // Update the separator
    $electrician_services_defaults['delimiter'] = $electrician_services_separator;

    return $electrician_services_defaults;
}
add_filter('woocommerce_breadcrumb_defaults', 'electrician_services_woocommerce_breadcrumb_separator');

//add animation class
if ( class_exists( 'WooCommerce' ) ) { 
	add_filter('post_class', function($electrician_services_classes, $class, $product_id) {
	    if( is_shop() || is_product_category() ){
	        
	        $electrician_services_classes = array_merge(['wow','swing'], $electrician_services_classes);
	    }
	    return $electrician_services_classes;
	},10,3);
}
//woocommerce-end//

// Get start function
function electrician_services_custom_admin_notice() {
    // Check if the notice is dismissed
    if (!get_user_meta(get_current_user_id(), 'dismissed_admin_notice', true)) {
        // Check if not on the theme documentation page
        $electrician_services_current_screen = get_current_screen();
        if ($electrician_services_current_screen && $electrician_services_current_screen->id !== 'appearance_page_electrician-services-guide-page') {
            $electrician_services_theme = wp_get_theme();
            ?>
            <div class="notice notice-info is-dismissible">
                <div class="notice-div">
                    <div>
                        <p class="theme-name"><?php echo esc_html($electrician_services_theme->get('Name')); ?></p>
                        <p><?php _e('For information and detailed instructions, check out our theme documentation.', 'electrician-services'); ?></p>
                    </div>
                    <a class="button-primary" href="themes.php?page=electrician-services-guide-page"><?php _e('Theme Documentation', 'electrician-services'); ?></a>
                </div>
            </div>
        <?php
        }
    }
}
add_action('admin_notices', 'electrician_services_custom_admin_notice');
// Dismiss notice function
function electrician_services_dismiss_admin_notice() {
    update_user_meta(get_current_user_id(), 'dismissed_admin_notice', true);
}
add_action('wp_ajax_electrician_services_dismiss_admin_notice', 'electrician_services_dismiss_admin_notice');
// Enqueue scripts and styles
function electrician_services_enqueue_admin_script($hook) {
    // Admin JS
    wp_enqueue_script('electrician-services-admin.js', get_theme_file_uri('/assets/js/electrician-services-admin.js'), array('jquery'), true);

    wp_localize_script('electrician-services-admin.js', 'electrician_services_scripts_localize', array(
        'ajax_url' => esc_url(admin_url('admin-ajax.php'))
    ));
}
add_action('admin_enqueue_scripts', 'electrician_services_enqueue_admin_script');
// Reset the dismissed notice status when the theme is switched
function electrician_services_after_switch_theme() {
    delete_user_meta(get_current_user_id(), 'dismissed_admin_notice');
}
add_action('after_switch_theme', 'electrician_services_after_switch_theme');
//get-start-function-end//

// tag count
function electrician_services_display_post_tag_count() {
    $electrician_services_tags = get_the_tags();
    $electrician_services_tag_count = ($electrician_services_tags) ? count($electrician_services_tags) : 0;
    $electrician_services_tag_text = ($electrician_services_tag_count === 1) ? 'tag' : 'tags';
    echo $electrician_services_tag_count . ' ' . $electrician_services_tag_text;
}

//media post format
function electrician_services_get_media($electrician_services_type = array()){
	$electrician_services_content = apply_filters( 'the_content', get_the_content() );
  	$output = false;

  // Only get media from the content if a playlist isn't present.
  if ( false === strpos( $electrician_services_content, 'wp-playlist-script' ) ) {
    $output = get_media_embedded_in_content( $electrician_services_content, $electrician_services_type );
    return $output;
  }
}

// front page template
function electrician_services_front_page_template( $template ) {
	return is_home() ? '' : $template;
}
add_filter( 'frontpage_template',  'electrician_services_front_page_template' );

// excerpt function
function electrician_services_custom_excerpt() {
    $electrician_services_excerpt = get_the_excerpt();
    $electrician_services_plain_text_excerpt = wp_strip_all_tags($electrician_services_excerpt);
    
    // Get dynamic word limit from theme mod
    $electrician_services_word_limit = esc_attr(get_theme_mod('electrician_services_post_excerpt', '30'));
    
    // Limit the number of words
    $electrician_services_limited_excerpt = implode(' ', array_slice(explode(' ', $electrician_services_plain_text_excerpt), 0, $electrician_services_word_limit));

    echo esc_html($electrician_services_limited_excerpt);
}

//typography
function electrician_services_fonts_scripts() {
	$headings_font = esc_html(get_theme_mod('electrician_services_headings_text'));
	$body_font = esc_html(get_theme_mod('electrician_services_body_text'));

	if( $headings_font ) {
		wp_enqueue_style( 'electrician-services-headings-fonts', '//fonts.googleapis.com/css?family='. $headings_font );
	} else {
		wp_enqueue_style( 'electrician-services-source-sans', '//fonts.googleapis.com/css?family=Lato:400,700,400italic,700italic');
	}
	if( $body_font ) {
		wp_enqueue_style( 'electrician-services-body-fonts', '//fonts.googleapis.com/css?family='. $body_font );
	} else {
		wp_enqueue_style( 'electrician-services-source-body', '//fonts.googleapis.com/css?family=Source+Sans+Pro:400,300,400italic,700,600');
	}
}
add_action( 'wp_enqueue_scripts', 'electrician_services_fonts_scripts' );

// Footer Text
function electrician_services_copyright_link() {
    $electrician_services_footer_text = get_theme_mod('electrician_services_footer_text', esc_html__('Electrician WordPress Theme', 'electrician-services'));
    $electrician_services_credit_link = esc_url('https://www.ovationthemes.com/wordpress/free-electrician-wordpress-theme/');

    echo '<a href="' . $electrician_services_credit_link . '" target="_blank">' . esc_html($electrician_services_footer_text) . '<span class="footer-copyright">' . esc_html__(' By Ovation Themes', 'electrician-services') . '</span></a>';
}

// custom sanitizations
// dropdown
function electrician_services_sanitize_dropdown_pages( $page_id, $setting ) {
	$page_id = absint( $page_id );
	return ( 'publish' == get_post_status( $page_id ) ? $page_id : $setting->default );
}
// slider custom control
if ( ! function_exists( 'electrician_services_sanitize_integer' ) ) {
	function electrician_services_sanitize_integer( $input ) {
		return (int) $input;
	}
}
// range contol
function electrician_services_sanitize_number_absint( $number, $setting ) {

	// Ensure input is an absolute integer.
	$number = absint( $number );

	// Get the input attributes associated with the setting.
	$atts = $setting->manager->get_control( $setting->id )->input_attrs;

	// Get minimum number in the range.
	$min = ( isset( $atts['min'] ) ? $atts['min'] : $number );

	// Get maximum number in the range.
	$max = ( isset( $atts['max'] ) ? $atts['max'] : $number );

	// Get step.
	$step = ( isset( $atts['step'] ) ? $atts['step'] : 1 );

	// If the number is within the valid range, return it; otherwise, return the default
	return ( $min <= $number && $number <= $max && is_int( $number / $step ) ? $number : $setting->default );
}
// select post page
function electrician_services_sanitize_select( $input, $setting ){
    $input = sanitize_key($input);
    $choices = $setting->manager->get_control( $setting->id )->choices;
    return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
}
// toggle switch
function electrician_services_callback_sanitize_switch( $value ) {
	// Switch values must be equal to 1 of off. Off is indicator and should not be translated.
	return ( ( isset( $value ) && $value == 1 ) ? 1 : 'off' );
}
//choices control
function electrician_services_sanitize_choices( $input, $setting ) {
    global $wp_customize;
    $control = $wp_customize->get_control( $setting->id );
    if ( array_key_exists( $input, $control->choices ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}
// phone number
function electrician_services_sanitize_phone_number( $phone ) {
  return preg_replace( '/[^\d+]/', '', $phone );
}

// Sanitize Sortable control.
function electrician_services_sanitize_sortable( $val, $setting ) {
	if ( is_string( $val ) || is_numeric( $val ) ) {
		return array(
			esc_attr( $val ),
		);
	}
	$sanitized_value = array();
	foreach ( $val as $item ) {
		if ( isset( $setting->manager->get_control( $setting->id )->choices[ $item ] ) ) {
			$sanitized_value[] = esc_attr( $item );
		}
	}
	return $sanitized_value;
}

// customizer dropdown
function electrician_services_slider_dropdown(){
	if(get_option('electrician_services_slider_arrows') == true ) {
		return true;
	}
	return false;
}
function electrician_services_project_dropdown(){
	if(get_option('electrician_services_project_enable') == true ) {
		return true;
	}
	return false;
}

// theme setup
function electrician_services_setup() {
	load_theme_textdomain( 'electrician-services', get_template_directory() . '/languages' );
	add_theme_support( 'woocommerce' );
	add_theme_support( "align-wide" );
	add_theme_support( "wp-block-styles" );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( "responsive-embeds" );
	add_theme_support( 'title-tag' );
	add_theme_support('custom-background',array(
		'default-color' => 'ffffff',
	));
	add_image_size( 'electrician-services-featured-image', 2000, 1200, true );
	add_image_size( 'electrician-services-thumbnail-avatar', 100, 100, true );

	$GLOBALS['content_width'] = 525;
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'electrician-services' ),
	) );

	add_theme_support( 'html5', array(
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	// Add theme support for Custom Logo.
	add_theme_support( 'custom-logo', array(
		'width'       => 250,
		'height'      => 250,
		'flex-width'  => true,
		'flex-height' => true,
	) );

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );
	/*
	 * Enable support for Post Formats.
	 *
	 * See: https://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array('video','gallery','audio','quote',) );
	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, and column width.
 	 */
	add_editor_style( array( 'assets/css/editor-style.css' ) );
}
add_action( 'after_setup_theme', 'electrician_services_setup' );

// widgets
function electrician_services_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'electrician-services' ),
		'id'            => 'sidebar-1',
		'description'   => __( 'Add widgets here to appear in your sidebar on blog posts and archive pages.', 'electrician-services' ),
		'before_widget' => '<section id="%1$s" class="widget wow zoomIn %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class="widget_container"><h3 class="widget-title">',
		'after_title'   => '</h3></div>',
	) );

	register_sidebar( array(
		'name'          => __( 'Page Sidebar', 'electrician-services' ),
		'id'            => 'sidebar-2',
		'description'   => __( 'Add widgets here to appear in your pages and posts', 'electrician-services' ),
		'before_widget' => '<section id="%1$s" class="widget wow zoomIn %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class="widget_container"><h3 class="widget-title">',
		'after_title'   => '</h3></div>',
	) );

	register_sidebar( array(
		'name'          => __( 'Sidebar 3', 'electrician-services' ),
		'id'            => 'sidebar-3',
		'description'   => __( 'Add widgets here to appear in your sidebar on blog posts and archive pages.', 'electrician-services' ),
		'before_widget' => '<section id="%1$s" class="widget wow zoomIn %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class="widget_container"><h3 class="widget-title">',
		'after_title'   => '</h3></div>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 1', 'electrician-services' ),
		'id'            => 'footer-1',
		'description'   => __( 'Add widgets here to appear in your footer.', 'electrician-services' ),
		'before_widget' => '<section id="%1$s" class="widget wow slideInLeft %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 2', 'electrician-services' ),
		'id'            => 'footer-2',
		'description'   => __( 'Add widgets here to appear in your footer.', 'electrician-services' ),
		'before_widget' => '<section id="%1$s" class="widget wow slideInLeft %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 3', 'electrician-services' ),
		'id'            => 'footer-3',
		'description'   => __( 'Add widgets here to appear in your footer.', 'electrician-services' ),
		'before_widget' => '<section id="%1$s" class="widget wow slideInRight %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 4', 'electrician-services' ),
		'id'            => 'footer-4',
		'description'   => __( 'Add widgets here to appear in your footer.', 'electrician-services' ),
		'before_widget' => '<section id="%1$s" class="widget wow slideInRight %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'electrician_services_widgets_init' );

//Enqueue scripts and styles.
function electrician_services_scripts() {

	require_once get_theme_file_path( 'inc/wptt-webfont-loader.php' );

	wp_enqueue_style(
		'noto',
		wptt_get_webfont_url( 'https://fonts.googleapis.com/css2?family=Noto+Sans:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900&display=swap' ),
		array(),
		'1.0'
	);

	//Bootstarp
	wp_enqueue_style( 'bootstrap-style', get_template_directory_uri().'/assets/css/bootstrap.css' );

	// Theme stylesheet.
	wp_enqueue_style( 'electrician-services-style', get_stylesheet_uri() );

	// Theme Customize CSS.
	require get_parent_theme_file_path( 'inc/extra_customization.php' );
	wp_add_inline_style( 'electrician-services-style',$electrician_services_custom_style );

	//font-awesome
	wp_enqueue_style( 'font-awesome-style', get_template_directory_uri().'/assets/css/fontawesome-all.css' );

	//Owl Carousel CSS
	wp_enqueue_style( 'owl.carousel-style', get_template_directory_uri().'/assets/css/owl.carousel.css' );

	// Block Style
	wp_enqueue_style( 'electrician-services-block-style', get_template_directory_uri().'/assets/css/blocks.css' );

	//Custom JS
	wp_enqueue_script( 'electrician-services-theme-script.js', get_theme_file_uri( '/assets/js/theme-script.js' ), array( 'jquery' ), true );

	//Nav Focus JS
	wp_enqueue_script( 'electrician-services-navigation-focus', get_theme_file_uri( '/assets/js/navigation-focus.js' ), array( 'jquery' ), true );


	//Bootstarp JS
	wp_enqueue_script( 'bootstrap-js', get_theme_file_uri( '/assets/js/bootstrap.js' ), array( 'jquery' ),true );

	//Owl Carousel JS
	wp_enqueue_script( 'owl.carousel-js', get_theme_file_uri( '/assets/js/owl.carousel.js' ), array( 'jquery' ),true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	if (get_option('electrician_services_animation_enable', false) !== 'off') {
		//wow.js
		wp_enqueue_script( 'electrician-services-wow-js', get_theme_file_uri( '/assets/js/wow.js' ), array( 'jquery' ), true );

		//animate.css
		wp_enqueue_style( 'electrician-services-animate-css', get_template_directory_uri().'/assets/css/animate.css' );
	}

	wp_enqueue_style( 'electrician-services-style', get_stylesheet_uri() );
	wp_style_add_data( 'electrician-services-style', 'rtl', 'replace' );
}
add_action( 'wp_enqueue_scripts', 'electrician_services_scripts' );

// Enqueue editor styles for Gutenberg
function electrician_services_block_editor_styles() {
	// Block styles.
	wp_enqueue_style( 'electrician-services-block-editor-style', trailingslashit( esc_url ( get_template_directory_uri() ) ) . '/assets/css/editor-blocks.css' );
}
add_action( 'enqueue_block_editor_assets', 'electrician_services_block_editor_styles' );

# Load scripts and styles.(fontawesome)
add_action( 'customize_controls_enqueue_scripts', 'electrician_services_customize_controls_register_scripts' );
function electrician_services_customize_controls_register_scripts() {
	
	wp_enqueue_style( 'electrician-services-ctypo-customize-controls-style', trailingslashit( esc_url(get_template_directory_uri()) ) . '/assets/css/customize-controls.css' );
}

// enque files
require get_parent_theme_file_path( '/inc/custom-header.php' );
require get_parent_theme_file_path( '/inc/template-tags.php' );
require get_parent_theme_file_path( '/inc/template-functions.php' );
require get_parent_theme_file_path( '/inc/typofont.php' );
require get_parent_theme_file_path( '/inc/customizer.php' );
require get_parent_theme_file_path( '/inc/dashboard/dashboard.php' );
require get_parent_theme_file_path( '/inc/breadcrumb.php' );
require get_parent_theme_file_path( '/inc/sortable/sortable_control.php' );